@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage 
     
-  Copyright (c) 2007-2010 Yoran Heling
+  Copyright (c) 2007-2011 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -71,6 +71,8 @@ struct dir {
 
 /* program state */
 extern int pstate;
+/* read-only flag */
+extern int read_only;
 /* minimum screen update interval when calculating, in ms */
 extern long update_delay;
 
